---
sidebar_position: 8
---

# BondAI Roadmap

## Our Mission

BondAI's forward looking goal is to integrate the latest research in building powerful AI Agents and make this functionality easy to use and integrate into any application. Additionally, we intend to expose this functionality to end users via an accessible assistant anyone can install on their own machine. Ultimately, we intend to develop a fully local, privately owned and operated AI system using a local LLM. We want this project to be part of the ecosystem of tools that counterbalance the consolidation of AI power currently owned by large corporations.

## Upcoming Features

- BondAI User Interface *(In Progress)*
- Agent Benchmarks
- Save/Restore agent state
- ToolMaker - A tool that makes tools ([see paper](https://arxiv.org/abs/2305.17126))
- Tool Repository ([see Voyager paper](https://arxiv.org/abs/2305.16291))
- Reasoning on Graphs ([see paper](https://arxiv.org/abs/2310.01061))
- Multi-Agent Systems Support (MAS) (see [AutoGen paper](https://browse.arxiv.org/pdf/2308.08155.pdf))
- Cognitive Architectures: Reflexion ([see paper](https://arxiv.org/abs/2303.11366))
- Cognitive Architectures: Tree of Thoughts ([see paper](https://arxiv.org/abs/2305.10601))
- Cognitive Architectures: Graph of Thoughts ([see paper](https://arxiv.org/abs/2308.09687))
- Finetuned Llama 2